@@ -10,7 +10,7 @@
 """
 
 from .endpoint import DeviceAuthorizationEndpoint
-from .grant import DeviceCodeGrant, DEVICE_CODE_GRANT_TYPE
+from .device_code import DeviceCodeGrant, DEVICE_CODE_GRANT_TYPE
 from .models import DeviceCredentialMixin, DeviceCredentialDict
 from .errors import AuthorizationPendingError, SlowDownError, ExpiredTokenError
 
